.. shade documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to shade's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   installation
   usage
   logging
   model
   contributing
   coding
   microversions
   releasenotes

.. include:: ../../README.rst

Presentations
=============

.. toctree::
   :maxdepth: 1

   multi-cloud-demo

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
